==> resin-4.0.27-src.tar.gz: resin-4.0.27/modules/kernel/src/com/caucho/config/async/AsyncQueue.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.config.async;

import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.TimeUnit;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.caucho.env.thread.AbstractTaskWorker;

/**
 * Represents the @Asynchronous interception
 */
public class AsyncQueue extends AbstractTaskWorker {
  private static final Logger log = Logger.getLogger(AsyncQueue.class.getName());
  
  private final ArrayBlockingQueue<Runnable> _queue
    = new ArrayBlockingQueue<Runnable>(1024);
  
  public void offer(Runnable task)
  {
    _queue.offer(task);
    
    wake();
  }
  
  @Override
  public final long runTask()
  {
    try {
      Runnable task;
      
      while ((task = _queue.poll(10, TimeUnit.MILLISECONDS)) != null) {
        task.run();
      }
    } catch (Exception e) {
      log.log(Level.WARNING, e.toString(), e);
    }
    
    return -1;
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/kernel/src/com/caucho/config/async/AsyncQueue.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.config.async;

import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.caucho.env.thread.AbstractTaskWorker;

/**
 * Represents the @Asynchronous interception
 */
public class AsyncQueue extends AbstractTaskWorker {
  private static final Logger log = Logger.getLogger(AsyncQueue.class.getName());
  
  private final LinkedBlockingQueue<Runnable> _queue
    = new LinkedBlockingQueue<Runnable>(1024);
  
  public void offer(Runnable task)
  {
    _queue.offer(task);
    
    wake();
  }
  
  @Override
  public final long runTask()
  {
    try {
      Runnable task;
      
      while ((task = _queue.poll(10, TimeUnit.MILLISECONDS)) != null) {
        task.run();
      }
    } catch (Exception e) {
      log.log(Level.WARNING, e.toString(), e);
    }
    
    return -1;
  }
}
